require 'test_helper'

class V1::CollectionsControllerTest < ActionController::TestCase
  tests V1::CollectionsController
  include Devise::TestHelpers

  test 'should get index' do
    skip('Unsolved issue: ArgumentError: wrong number of arguments (2 for 0)')
  end

  test 'should user post collection to create and return :created code' do
    auth_request users(:jack)
    post :create, collection: {name: 'my collection',
                               description: 'testing collection',
                               owner_type: 'User', owner_id: users(:jack).id
    }
    assert_response :created
  end

  test 'should institution post collection to create and return :created code' do
    auth_request users(:jack)
    post :create, collection: {name: 'my collection',
                               description: 'testing collection',
                               owner_type: 'Institution', owner_id: institutions(:ufpr).id
    }
    assert_response :created
  end

  test 'should user post collection to create and return :unauthorized code' do
    post :create, collection: {name: 'my collection',
                               description: 'testing collection',
                               owner_type: 'Institution', owner_id: institutions(:ufpr).id
    }
    assert_response :unauthorized
  end

  test 'should user tagging a collection' do
    auth_request users(:jack)

    post :tagging, id: collections(:ufpr).id, tag: { name: 'Test' }
    assert_response :created
  end

  test 'should user untagging a collection' do
    auth_request users(:jack)

    post :tagging, id: collections(:ufpr).id, tag: { name: 'Test' }
    assert_response :created

    delete :untagging, id: collections(:ufpr).id, tag: { name: 'Test' }
    assert_response :ok
  end

  test 'should user untagging a collection tagged by another user' do
    auth_request users(:jack)

    post :tagging, id: collections(:ufpr).id, tag: { name: 'Test' }
    assert_response :created

    auth_request users(:john)

    delete :untagging, id: collections(:ufpr).id, tag: { name: 'Test' }
    assertok_response :unprocessable_entity
  end

  test 'should user untagging a tag that does not exist' do
    auth_request users(:jack)

    post :tagging, id: collections(:ufpr).id, tag: { name: 'Test' }
    assert_response :created

    delete :untagging, id: collections(:ufpr).id, tag: { name: 'Test2' }
    assertok_response :unprocessable_entity
  end

  private

  def ensure_collection_is_persisted!(collection)
    collection.save!
  end
end
